/*******************************************************************************
* File Name: main.c
 *
 * Copyright CONSULTRON, 2020
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONSULTRON allows PUBLIC use of the file.
 * CONSULTRON provides NO WARRANTY expressed or implied.
*/
/*******************************************************************************
 * 
 * This is a demo using multiple instances of Term (1 as USBUART type and 3 as UART type).
 * It also has some adaptions to verify the operation of the improvements to the Term v2.3
 *
 * This demo was compiled for a CY8CKIT-059.  It can be adapted for any PSoC5.
 * Components used:
 * Term_USBUART is the Kit's Target USB_UART with a VBUS detection on pin P12.3
 *                  Short this pin to +5V to see an output change on the Term_UART.
 * Term_UART is the KitProg's COM port using P12.6 (Rx) and P12.7 (Tx)
 * Term_UART_1 is a UART using P12.0 (Rx) and P12.1 (Tx) with a VBUS detection on pin P12.2
 *                  Short this pin to +5V to see an output change on the Term_UART.
 * Term_UART_1 is a UART using P12.4 (Rx) and P12.5 (Tx)
*/
#include "project.h"
#include "version.h"
#include <stdio.h>


#define STRINGIFY(x) #x
#define TOSTRING(x) STRINGIFY(x)

_Bool sec_1 = 0;
//---------------------------------------------------------------------
CY_ISR(isr_systick_0)
{
static int16_t i = 0;
	i++;
	if(i >= 1000) {sec_1 = 1; i=0; }
}

//---------------------------------------------------------------------
int main(void)
{
char tstr[100];

    CyGlobalIntEnable; /* Enable global interrupts. */
	Term_USBUART_Start();
	Term_UART_Start();
	Term_UART_1_Start();
	Term_UART_2_Start();
    /* Place your initialization/startup code here (e.g. MyInst_Start()) */
	CySysTickStart();
	CySysTickSetCallback(0,&isr_systick_0);

    for(;;)
    {
	static uint32_t count;
	char c;

		while(sec_1 == 0)
		{	// loop while flag not set
			if( (c= Term_USBUART_GetChar()) != '\0') /* If there is an input character */
			{                                        
				Term_USBUART_PutChar(c);            /* Echo back to the same port */
			}
			if( (c= Term_UART_GetChar()) != '\0') /* If there is an input character */
			{                                     
				Term_UART_PutChar(c);             /* Echo back to the same port */
			}
			if( (c= Term_UART_1_GetChar()) != '\0') /* If there is an input character */
			{                                       
				Term_UART_1_PutChar(c);             /* Echo back to the same port */
			}
			if( (c= Term_UART_2_GetChar()) != '\0') /* If there is an input character */
			{
				Term_UART_2_PutChar(c);             /* Echo back to the same port */
			}
		}
		sec_1 = 0;	// reset the flag
		PIN_LED_BLUE_Write(1);
		snprintf(tstr, sizeof(tstr), "%s %s count=%u\t", CY_PROJECT_NAME, TOSTRING(SW_VER_REV_REL), count);
		Term_USBUART_PutString(tstr);
		Term_UART_PutString(tstr);
		Term_UART_1_PutString(tstr);
		Term_UART_2_PutString(tstr);
        Term_UART_PutChar((Term_UART_1_VBusPresent()==TRUE?'>':'<'));  /* Display the results of P12.2 VBUS detection */
        Term_UART_PutChar((Term_USBUART_VBusPresent()==TRUE?'+':'-'));  /* Display the results of P12.3 VBUS detection */
        Term_UART_PutChar('\t');
		count++;
		PIN_LED_BLUE_Write(0);
        /* Place your application code here. */
    }
}

/* [] END OF FILE */
